diff decoders/voc.c @ 221:c9772a9f5271

Initial implementation or stubs for rewind method. Other cleanups.
author Ryan C. Gordon <icculus@icculus.org>
date Thu, 17 Jan 2002 20:53:53 +0000
parents 47cc2de2ae36
children 1bafef18dabf
line wrap: on
line diff
--- a/decoders/voc.c	Thu Jan 17 20:53:03 2002 +0000
+++ b/decoders/voc.c	Thu Jan 17 20:53:53 2002 +0000
@@ -58,6 +58,7 @@
 static int VOC_open(Sound_Sample *sample, const char *ext);
 static void VOC_close(Sound_Sample *sample);
 static Uint32 VOC_read(Sound_Sample *sample);
+static int VOC_rewind(Sound_Sample *sample);
 
 static const char *extensions_voc[] = { "VOC", NULL };
 const Sound_DecoderFunctions __Sound_DecoderFunctions_VOC =
@@ -69,11 +70,12 @@
         "http://www.icculus.org/SDL_sound/"
     },
 
-    VOC_init,       /*  init() method */
-    VOC_quit,       /*  quit() method */
-    VOC_open,       /*  open() method */
-    VOC_close,      /* close() method */
-    VOC_read        /*  read() method */
+    VOC_init,       /*   init() method */
+    VOC_quit,       /*   quit() method */
+    VOC_open,       /*   open() method */
+    VOC_close,      /*  close() method */
+    VOC_read,       /*   read() method */
+    VOC_rewind      /* rewind() method */
 };
 
 
@@ -487,6 +489,15 @@
     return(v->bufpos);
 } /* VOC_read */
 
+
+static int VOC_rewind(Sound_Sample *sample)
+{
+    /* !!! FIXME. */
+    SNDDBG(("VOC_rewind(): Write me!\n"));
+    assert(0);
+    return(0);
+} /* VOC_rewind */
+
 #endif /* SOUND_SUPPORTS_VOC */
 
 /* end of voc.c ... */